from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from teralytic.api.organization_api import OrganizationApi
from teralytic.api.soils_api import SoilsApi
from teralytic.api.telemetry_api import TelemetryApi



# coding: utf-8

"""
    teralytic

    The Teralytic API allows clients to manage their organization, view their fields and and probes, and query sensor readings and analytics.  For sandbox testing you may use the api key: `swagger.teralytic.io`   # noqa: E501

    OpenAPI spec version: 1.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import teralytic
from teralytic.api.soils_api import SoilsApi  # noqa: E501
from teralytic.rest import ApiException


class TestSoilsApi(unittest.TestCase):
    """SoilsApi unit test stubs"""

    def setUp(self):
        self.api = teralytic.api.soils_api.SoilsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_query(self):
        """Test case for query

        Query the soildb  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
